@@ -22,13 +22,6 @@ int main(int argc, char *argv[])
         }
     }
 
-    auto optionsResult = Options::getOptions(argc, argv);
-
-    if (!optionsResult.has_value()) {
-        std::cout << optionsResult.error() << std::endl;
-        return 1;
-    }
-
     auto [
         connectionProvider,
         connectionKey,
@@ -36,7 +29,14 @@ int main(int argc, char *argv[])
         connectionRoleInstruction,
         connectionDetailedInstructions,
         connectionContent
-        ] = optionsResult.value();
+        ] = Options::getOptions(argc, argv);
+
+    if (connectionKey.empty() || connectionModel.empty() || connectionContent.empty()) {
+        std::cout << "Exited without any API connection." << std::endl;
+        return 0;
+    }
+
+    std::cout << "An API connection is started. Please wait for the AI's reply." << std::endl;
 
     auto reply = Net::aiDispatcher(
         connectionProvider,
