@@ -8,23 +8,29 @@
 class Options {
 
 public:
-    static std::expected<std::array<std::string, 6>, std::string> getOptions(int argc, char** argv);
+
+    static std::array<std::string, 6> getOptions(int argc, char** argv);
 
 private:
+
     static std::string selectProvider(const std::string& purpose);
+
     static std::string selectKey(
         const std::unordered_map<std::string, std::string>& keys,
         const std::string& purpose
     );
+
     static std::string selectModel(
         const std::unordered_map<std::string, std::unordered_map<std::string, std::string>>& models,
         const std::string& purpose
     );
+
     static std::string selectRole(
         const std::unordered_map<std::string, std::array<std::string, 2>>& roles,
         const std::string& purpose
     );
 
+    static std::string receiveMultiLines();
 };
 
 #endif //LIBAICONNECT_OPTIONS_H
\ No newline at end of file
